@@ -38,6 +38,8 @@ class ReadOnly(BasePermission):
 class IsEmailVerified(BasePermission):
     def has_permission(self, request, view):
         user = request.user
+        if user.is_anonymous:
+            return False
         try:
             email_address = user.emailaddress_set.get(email=user.email)
             return email_address.verified
